NAME
RT-Extension-ExcelFeed
DESCRIPTION
This extenstion allows you to generate RT reports in MS Excel XSLX format. It provides two ways to do this. First, it adds a new MS Excel option to the 'Feeds' menu on the Query Builder search results page. It also adds an option to the Dashboard subscription page that allows you to have scheduled dashboards emailed to recipients as attached MS Excel files rather than inline HTML reports.
RT VERSION
Works with RT 6.0. For RT 5.0 install the latest 0.* version.
INSTALLATION
perl Makefile.PLmakemake install-
May need root permissions
- Add this line to /opt/rt6/etc/RT_SiteConfig.pm
-
Plugin('RT::Extension::ExcelFeed'); - Clear your mason cache
-
rm -rf /opt/rt6/var/mason_data/obj - Restart your webserver
CONFIGURATION
$HideChartDownloadButton-
By default, a "Download as Microsoft Execel Spreadsheet" button is enabled on Charts. You can disable it by adding the following config to your RT_SiteConfig.pm:
Set( $HideChartDownloadButton, 1 ); $ExcelFeedProgressiveRows-
When generating an Excel file, ExcelFeed progressively pages through the search results
$ExcelFeedProgressiveRowsrows at a time. This does not change the output, but can significantly reduce memory usage on large result sets.Set this to 0 to disable progressive generation and load the entire result set into memory at once:
Set( $ExcelFeedProgressiveRows, 0 );If this option is not defined, ExcelFeed falls back to RT's core
$ProgressiveSearchResultRows, and if that is also not defined, to 1000.
AUTHOR
Best Practical Solutions, LLC <modules@bestpractical.com>
BUGS
All bugs should be reported via email to
L<bug-RT-Extension-ExcelFeed@rt.cpan.org|mailto:bug-RT-Extension-ExcelFeed@rt.cpan.org>
or via the web at
L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RT-Extension-ExcelFeed>.
LICENSE AND COPYRIGHT
This software is Copyright (c) 2015-2026 by Best Practical Solutions, LLC
This is free software, licensed under:
The GNU General Public License, Version 2, June 1991